#!/bin/sh
rm /usr/local/bin/tunapie
rm -rf /usr/local/share/tunapie
rm /etc/tunapie.config
rm src/*.pyc
rm /usr/local/share/pixmaps/tplogo.xpm
rmdir -p /usr/local/share/pixmaps
rm /usr/local/man/man1/tunapie.1
rmdir -p /usr/local/man/man1/
rm /usr/local/share/applications/tunapie.desktop
